==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/it/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Salvataggio dei dati avvenuto con sucesso',
'L_UPDATE_TITLE'					=> 'Aggiornamento PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml richiede PHP5 o superiore per funzionare.',

'L_SELECT_LANG'						=> 'Seleziona la lingua',
'L_INPUT_CHANGE'					=> 'Cambia',

'L_UPDATE_UPTODATE'					=> 'PluXml è già alla versione più recente.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Nessun aggiornamento disponibile.',
'L_UPDATE_BACK'						=> 'Ritorna al sito',
'L_UPDATE_WARNING1'					=> 'Stai per aggiornare PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Seleziona la versione di PluXml da aggiornare.',
'L_UPDATE_WARNING2'					=> 'Se la vecchia versione di PluXml non è presente nella lista, non esiste una procedura automatizzata di aggiornamento perchè la versione in uso è troppo vecchia.<br />Scaricare l\'ultima versione di <a href="http://www.pluxml.org">PluXml</a> e procedere con una nuova installazione.',
'L_UPDATE_WARNING3'					=> 'Attenzione, prima di eseguire l\'aggiornamento, eseguire un backup della cartella "data"',
'L_UPDATE_START'					=> 'Inizia l\'aggiornamento',

'L_UPDATE_ENDED'					=> 'Aggiornamento completato.',
'L_UPDATE_INPROGRESS'				=> 'Aggiornamento in corso',
'L_UPDATE_ERROR'					=> 'Errore durante l\'aggiornamento.',
'L_UPDATE_SUCCESSFUL'				=> 'Tutti gli aggiornamenti sono stati eseguiti con successo !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Aggiornamento del file parametres.xml', //pas traduit le nom des fichiers xml
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Creazione del file tags.xml',//pas traduit le nom des fichiers xml
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Errore durante la creazione del file tags.xml',//pas traduit le nom des fichiers xml
'L_UPDATE_CREATE_THEME_FILE'		=> 'Creazione del file del tema',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Errore durante la creazione del file',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversione degli articoli nel nuovo formato',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Errore durante l\'elaborazione',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migrazione delle pagine statiche',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Errore durante la migrazione del file delle pagine statiche',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Creazione del file degli utenti',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Errore durante la creazione del file degli utenti',
'L_UPDATE_USERS_MIGRATION'			=> 'Migrazione del file degli utenti',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Errore durante la migrazione del file degli utenti',
'L_UPDATE_ERR_NO_USERS'				=> 'Nessun utente presente nel file',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Creazione del file .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Errore durante la creazione del file .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Aggiornare il file .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Errore durante l\'aggiornamento del file .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migrazione del file delle categorie',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Errore durante la migrazione del file delle categorie',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Creazione del file plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Errore durante creazione del file plugins.xml',//pas traduit le nom des fichiers xml
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Cancellazione del file core/admin/fullscreen.php',	//pas traduit le nom des fichiers xml
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Errore durante la cancellazione del file core/admin/fullscreen.php',//pas traduit le nom des fichiers xml
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Cancellazione della cartella core/plxtoolbar/',//pas traduit le nom des fichiers xml
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Errore durante la cancellazione della cartella core/plxtoolbar/',//pas traduit le nom des fichiers xml
'L_UPDATE_FILE'						=> 'Aggiornamento File',
'L_UPDATE_ERR_FILE'					=> 'Errore durante il file di aggiornamento',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'La migrazione di file dalle impostazioni dei parametri del plugin nel file di configurazione',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Aggiornamento del file plugins.xml',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/it/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Salvataggio dei dati avvenuto con sucesso',
'L_UPDATE_TITLE'					=> 'Aggiornamento PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml richiede PHP5 o superiore per funzionare.',

'L_SELECT_LANG'						=> 'Seleziona la lingua',
'L_INPUT_CHANGE'					=> 'Cambia',

'L_UPDATE_UPTODATE'					=> 'PluXml è già alla versione più recente.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Nessun aggiornamento disponibile.',
'L_UPDATE_BACK'						=> 'Ritorna al sito',
'L_UPDATE_WARNING1'					=> 'Stai per aggiornare PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Seleziona la versione di PluXml da aggiornare.',
'L_UPDATE_WARNING2'					=> 'Se la vecchia versione di PluXml non è presente nella lista, non esiste una procedura automatizzata di aggiornamento perchè la versione in uso è troppo vecchia.<br />Scaricare l\'ultima versione di <a href="http://www.pluxml.org">PluXml</a> e procedere con una nuova installazione.',
'L_UPDATE_WARNING3'					=> 'Attenzione, prima di eseguire l\'aggiornamento, eseguire un backup della cartella "data"',
'L_UPDATE_START'					=> 'Inizia l\'aggiornamento',

'L_UPDATE_ENDED'					=> 'Aggiornamento completato.',
'L_UPDATE_INPROGRESS'				=> 'Aggiornamento in corso',
'L_UPDATE_ERROR'					=> 'Errore durante l\'aggiornamento.',
'L_UPDATE_SUCCESSFUL'				=> 'Tutti gli aggiornamenti sono stati eseguiti con successo !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Aggiornamento del file parametres.xml', //pas traduit le nom des fichiers xml
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Creazione del file tags.xml',//pas traduit le nom des fichiers xml
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Errore durante la creazione del file tags.xml',//pas traduit le nom des fichiers xml
'L_UPDATE_CREATE_THEME_FILE'		=> 'Creazione del file del tema',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Errore durante la creazione del file',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversione degli articoli nel nuovo formato',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Errore durante l\'elaborazione',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migrazione delle pagine statiche',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Errore durante la migrazione del file delle pagine statiche',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Creazione del file degli utenti',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Errore durante la creazione del file degli utenti',
'L_UPDATE_USERS_MIGRATION'			=> 'Migrazione del file degli utenti',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Errore durante la migrazione del file degli utenti',
'L_UPDATE_ERR_NO_USERS'				=> 'Nessun utente presente nel file',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Creazione del file .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Errore durante la creazione del file .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Aggiornare il file .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Errore durante l\'aggiornamento del file .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migrazione del file delle categorie',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Errore durante la migrazione del file delle categorie',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Creazione del file plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Errore durante creazione del file plugins.xml',//pas traduit le nom des fichiers xml
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Cancellazione del file core/admin/fullscreen.php',	//pas traduit le nom des fichiers xml
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Errore durante la cancellazione del file core/admin/fullscreen.php',//pas traduit le nom des fichiers xml
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Cancellazione della cartella core/plxtoolbar/',//pas traduit le nom des fichiers xml
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Errore durante la cancellazione della cartella core/plxtoolbar/',//pas traduit le nom des fichiers xml
'L_UPDATE_FILE'						=> 'Aggiornamento File',
'L_UPDATE_ERR_FILE'					=> 'Errore durante il file di aggiornamento',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'La migrazione di file dalle impostazioni dei parametri del plugin nel file di configurazione',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Aggiornamento del file plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Commenti migrazione',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Errore durante la migrazione commenti',
);
?>
